@@ -18,10 +18,12 @@ along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from libopensesame.py3compat import *
-from lsp_code_edit_widgets import LanguageServerCodeEdit
+from lsp_code_edit_widgets._language_server_code_edit import \
+    LanguageServerCodeEdit
 
 
 class RCodeEdit(LanguageServerCodeEdit):
+    """https://github.com/REditorSupport/languageserver"""
     
     mimetypes = ['text/x-r', 'text/x-R']
     language_server_command = 'R --slave -e "languageserver::run()"'
